@@ -1,5 +1,6 @@
 """Environment wrapper that runs multiple environments."""
 import copy
+import warnings
 
 import numpy as np
 
@@ -22,6 +23,13 @@ class VecEnvExecutor:
         self.ts = np.zeros(len(self.envs), dtype='int')
         self.max_path_length = max_path_length
 
+        warnings.warn(
+            DeprecationWarning(
+                'VecEnvExecutor is deprecated, and will be removed in the '
+                'next release. Please use VecWorker and one of the new '
+                'samplers which implement garage.sampler.Sampler, such as '
+                'RaySampler'))
+
     def step(self, action_n):
         """Step all environments using the provided actions.
 
