@@ -6,9 +6,14 @@ import tensorflow as tf
 
 from garage.envs import GarageEnv
 from garage.tf.policies import GaussianLSTMPolicy
-from tests.fixtures import TfGraphTestCase
-from tests.fixtures.envs.dummy import DummyBoxEnv
-from tests.fixtures.envs.dummy import DummyDiscreteEnv
+
+# yapf: disable
+from tests.fixtures import TfGraphTestCase  # noqa: I202
+from tests.fixtures.envs.dummy import (DummyBoxEnv,
+                                       DummyDictEnv,
+                                       DummyDiscreteEnv)
+
+# yapf: enable
 
 
 class TestGaussianLSTMPolicy(TfGraphTestCase):
@@ -43,6 +48,22 @@ class TestGaussianLSTMPolicy(TfGraphTestCase):
         for action in actions:
             assert env.action_space.contains(action)
 
+    def test_get_action_dict_space(self):
+        env = GarageEnv(
+            DummyDictEnv(obs_space_type='box', act_space_type='box'))
+        policy = GaussianLSTMPolicy(env_spec=env.spec,
+                                    hidden_dim=4,
+                                    state_include_action=False)
+        policy.reset(do_resets=None)
+        obs = env.reset()
+
+        action, _ = policy.get_action(obs)
+        assert env.action_space.contains(action)
+
+        actions, _ = policy.get_actions([obs, obs])
+        for action in actions:
+            assert env.action_space.contains(action)
+
     # yapf: disable
     @pytest.mark.parametrize('obs_dim, action_dim, hidden_dim', [
         ((1, ), (1, ), 4),
